@@ -1,10 +1,10 @@
 package Labyrinth::Request;
 
-#use warnings;
-#use strict;
+use warnings;
+use strict;
 
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = '5.00';
+$VERSION = '5.01';
 
 =head1 NAME
 
